Module: ChefWorkstationInitialize

Defined in:
lib/selfbootstrap/nochef/suites.rb,
lib/selfbootstrap.rb,
lib/selfbootstrap/nochef.rb,
lib/selfbootstrap/withchef.rb,
lib/selfbootstrap/nochef/git.rb,
lib/selfbootstrap/nochef/ssh.rb,
lib/selfbootstrap/withlogger.rb,
lib/selfbootstrap/nochef/chef.rb,
lib/selfbootstrap/nochef/berks.rb,
lib/selfbootstrap/nochef/knife.rb,
lib/selfbootstrap/nochef/users.rb,
lib/selfbootstrap/withchef/git.rb,
lib/selfbootstrap/nochef/update.rb,
lib/selfbootstrap/withchef/chef.rb,
lib/selfbootstrap/nochef/kitchen.rb,
lib/selfbootstrap/withchef/users.rb,
lib/selfbootstrap/nochef/chefrepo.rb,
lib/selfbootstrap/nochef/platforms.rb,
lib/selfbootstrap/nochef/verifiers.rb,
lib/selfbootstrap/withchef/chefrepo.rb,
lib/selfbootstrap/nochef/commandline.rb,
lib/selfbootstrap/nochef/workstation.rb,
lib/selfbootstrap/nochef/provisioners.rb,
lib/selfbootstrap/nochef/selfbootstrap.rb,
lib/selfbootstrap/withchef/commandline.rb,
lib/selfbootstrap/withchef/workstation.rb,
lib/selfbootstrap/nochef/defaultmethods.rb,
lib/selfbootstrap/withchef/selfbootstrap.rb,
lib/selfbootstrap/withchef/defaultmethods.rb,
lib/selfbootstrap/withlogger/selfbootstrap.rb,
lib/selfbootstrap/withlogger/defaultmethods.rb,
lib/selfbootstrap/nochef/workstationresource.rb,
lib/selfbootstrap/withchef/workstationresource.rb,
lib/selfbootstrap/withlogger/workstationresource.rb,
lib/selfbootstrap/nochef/defaultworkstationresource.rb

Overview

This module name was auto-generated from the cookbook name. This name is a single word that starts with a capital letter and then continues to use camel-casing throughout the remainder of the name.

Defined Under Namespace

Modules: SelfBootstrap