Module: ChefWorkstationInitialize::SelfBootstrap::NoChef::SuitesHelpers
- Included in:
- PlatformsHelpers
- Defined in:
- lib/selfbootstrap/nochef/suites.rb
Instance Method Summary collapse
-
#default_suites ⇒ Object
Define the methods that you would like to assist the work you do in recipes, resources, or templates.
Instance Method Details
#default_suites ⇒ Object
Define the methods that you would like to assist the work you do in recipes, resources, or templates.
def my_helper_method # # help method implementation end
22 23 24 |
# File 'lib/selfbootstrap/nochef/suites.rb', line 22 def default_suites workstation_resource[:suites] end |